@@ -55,21 +55,24 @@ def get_changed_files(new, old):
     )[1].splitlines()
 
 
-def _run_single_hook(runner, repository, hook, args, write, skips=set()):
+def get_filenames(args, include_expr, exclude_expr):
     if args.origin and args.source:
-        get_filenames = git.get_files_matching(
+        getter = git.get_files_matching(
             lambda: get_changed_files(args.origin, args.source),
         )
     elif args.files:
-        get_filenames = git.get_files_matching(lambda: args.files)
+        getter = git.get_files_matching(lambda: args.files)
     elif args.all_files:
-        get_filenames = git.get_all_files_matching
+        getter = git.get_all_files_matching
     elif git.is_in_merge_conflict():
-        get_filenames = git.get_conflicted_files_matching
+        getter = git.get_conflicted_files_matching
     else:
-        get_filenames = git.get_staged_files_matching
+        getter = git.get_staged_files_matching
+    return getter(include_expr, exclude_expr)
 
-    filenames = get_filenames(hook['files'], hook['exclude'])
+
+def _run_single_hook(hook, repo, args, write, skips=frozenset()):
+    filenames = get_filenames(args, hook['files'], hook['exclude'])
     if hook['id'] in skips:
         _print_user_skipped(hook, write, args)
         return 0
@@ -82,7 +85,7 @@ def _run_single_hook(runner, repository, hook, args, write, skips=set()):
     write(get_hook_message(_hook_msg_start(hook, args.verbose), end_len=6))
     sys.stdout.flush()
 
-    retcode, stdout, stderr = repository.run_hook(hook, filenames)
+    retcode, stdout, stderr = repo.run_hook(hook, filenames)
 
     if retcode != hook['expected_return_value']:
         retcode = 1
@@ -106,32 +109,19 @@ def _run_single_hook(runner, repository, hook, args, write, skips=set()):
     return retcode
 
 
-def _run_hooks(runner, args, write, environ):
+def _run_hooks(repo_hooks, args, write, environ):
     """Actually run the hooks."""
-    retval = 0
-
     skips = _get_skips(environ)
-
-    for repo in runner.repositories:
-        for _, hook in repo.hooks:
-            retval |= _run_single_hook(
-                runner, repo, hook, args, write, skips=skips,
-            )
-
+    retval = 0
+    for repo, hook in repo_hooks:
+        retval |= _run_single_hook(hook, repo, args, write, skips)
     return retval
 
 
-def _run_hook(runner, args, write):
-    hook_id = args.hook
+def get_repo_hooks(runner):
     for repo in runner.repositories:
-        for hook_id_in_repo, hook in repo.hooks:
-            if hook_id == hook_id_in_repo:
-                return _run_single_hook(
-                    runner, repo, hook, args, write=write,
-                )
-    else:
-        write('No hook with id `{0}`\n'.format(hook_id))
-        return 1
+        for _, hook in repo.hooks:
+            yield (repo, hook)
 
 
 def _has_unmerged_paths(runner):
@@ -139,6 +129,15 @@ def _has_unmerged_paths(runner):
     return bool(stdout.strip())
 
 
+def _has_unstaged_config(runner):
+    retcode, _, _ = runner.cmd_runner.run(
+        ('git', 'diff', '--exit-code', runner.config_file_path),
+        retcode=None,
+    )
+    # be explicit, other git errors don't mean it has an unstaged config.
+    return retcode == 1
+
+
 def run(runner, args, write=sys_stdout_write_wrapper, environ=os.environ):
     # Set up our logging handler
     logger.addHandler(LoggingHandler(args.color, write=write))
@@ -151,6 +150,21 @@ def run(runner, args, write=sys_stdout_write_wrapper, environ=os.environ):
     if bool(args.source) != bool(args.origin):
         logger.error('Specify both --origin and --source.')
         return 1
+    if _has_unstaged_config(runner) and not args.no_stash:
+        if args.allow_unstaged_config:
+            logger.warn(
+                'You have an unstaged config file and have specified the '
+                '--allow-unstaged-config option.\n'
+                'Note that your config will be stashed before the config is '
+                'parsed unless --no-stash is specified.',
+            )
+        else:
+            logger.error(
+                'Your .pre-commit-config.yaml is unstaged.\n'
+                '`git add .pre-commit-config.yaml` to fix this.\n'
+                'Run pre-commit with --allow-unstaged-config to silence this.'
+            )
+            return 1
 
     # Don't stash if specified or files are specified
     if args.no_stash or args.all_files or args.files:
@@ -159,7 +173,13 @@ def run(runner, args, write=sys_stdout_write_wrapper, environ=os.environ):
         ctx = staged_files_only(runner.cmd_runner)
 
     with ctx:
+        repo_hooks = list(get_repo_hooks(runner))
         if args.hook:
-            return _run_hook(runner, args, write=write)
-        else:
-            return _run_hooks(runner, args, write=write, environ=environ)
+            repo_hooks = [
+                (repo, hook) for repo, hook in repo_hooks
+                if hook['id'] == args.hook
+            ]
+            if not repo_hooks:
+                write('No hook with id `{0}`\n'.format(args.hook))
+                return 1
+        return _run_hooks(repo_hooks, args, write, environ)
