@@ -1,11 +1,13 @@
 from __future__ import unicode_literals
 
 import argparse
+import os
 import sys
 
 import pkg_resources
 
 from pre_commit import color
+from pre_commit import five
 from pre_commit.commands.autoupdate import autoupdate
 from pre_commit.commands.clean import clean
 from pre_commit.commands.install_uninstall import install
@@ -15,8 +17,16 @@ from pre_commit.error_handler import error_handler
 from pre_commit.runner import Runner
 
 
+# https://github.com/pre-commit/pre-commit/issues/217
+# On OSX, making a virtualenv using pyvenv at . causes `virtualenv` and `pip`
+# to install packages to the wrong place.  We don't want anything to deal with
+# pyvenv
+os.environ.pop('__PYVENV_LAUNCHER__', None)
+
+
 def main(argv=None):
     argv = argv if argv is not None else sys.argv[1:]
+    argv = [five.to_text(arg) for arg in argv]
     parser = argparse.ArgumentParser()
 
     # http://stackoverflow.com/a/8521644/812183
@@ -86,6 +96,11 @@ def main(argv=None):
         '--source', '-s',
         help='The remote branch"s commit_id when using `git push`',
     )
+    run_parser.add_argument(
+        '--allow-unstaged-config', default=False, action='store_true',
+        help='Allow an unstaged config to be present.  Note that this will'
+        'be stashed before parsing unless --no-stash is specified'
+    )
     run_mutex_group = run_parser.add_mutually_exclusive_group(required=False)
     run_mutex_group.add_argument(
         '--all-files', '-a', action='store_true', default=False,
